@@ -24,24 +24,39 @@ class IsModerator(object):
         """ Devuelve True o False """
 
         #print request
-        #print request.user
-        #print view_func.__name__
+        print request.user
+        print view_func.__name__
         #print view_kwargs['slug']
-        #print view_kwargs
+        print view_kwargs
+
+        # request.user: AnonymousUser
+        # view_func.__name__: TopicDelete
+        # view_kwargs: {'topicslug': u'primer-partido-20132014-lugo-numancia'}
+        # [20/Aug/2013 12:55:27] "GET /foro-cdlugo/delete-topic/primer-partido-20132014-lugo-numancia/ HTTP/1.1" 302 0
 
         functionlist = ['PostUpdate', 'PostDelete', 'TopicAction', 'TopicDelete']
 
         try:
             if view_func.__name__ in functionlist:
-            #if any(view_func.__name__ in s for s in functionlist):
-                if view_kwargs['topicslug']:
-                    if utils.es_suyo(request.user, view_kwargs['id']) and view_func.__name__ == 'PostUpdate':
+
+                if view_kwargs['topicslug'] and view_func.__name__ == 'TopicDelete':
+                    if utils.es_moderador(request.user, view_kwargs['topicslug']):
                         return None
+                    else:
+                        messages.add_message(request, messages.ERROR, _('No puedes eliminar un topic si no eres moderador o admin.'))
+                        return redirect('account_profile')
+
+                if view_kwargs['topicslug'] and view_kwargs['id'] and (view_func.__name__ == 'PostUpdate' or view_func.__name__ == 'PostDelete'):
+                    if utils.es_suyo(request.user, view_kwargs['id']):
+                        return None
+                    else:
+                        messages.add_message(request, messages.ERROR, _('No puedes editar o eliminar un post que no es tuyo.'))
+                        return redirect('account_profile')
 
                     if utils.es_moderador(request.user, view_kwargs['topicslug']):
                         return None
                     else:
-                        messages.add_message(request, messages.ERROR, _('No eres moderador, cuidado con lo que haces'))
+                        messages.add_message(request, messages.ERROR, _('No eres moderador, cuidado con lo que haces.'))
                         return redirect('account_profile')
         except:
             return None
