@@ -141,6 +141,7 @@ class TopicCreate(FormView):
                                    post_count = 1,
                                    topic_count = 1,
                                    hits = 1,
+                                   status = 1,
                                    sticky = 0,
                                    closed = 0 )
         newtopic.save()
@@ -208,7 +209,9 @@ class TopicDelete(DeleteView):
 
     def get(self, request, *args, **kwargs):
         topic = get_object_or_404(mymodels.Topic, slug=self.kwargs['topicslug'])
-        topic.delete()
+        topic.status=0
+        topic.save()
+        #topic.delete()
         return redirect('app_forum-forum-detail', topic.forum.slug)
 
 
@@ -245,7 +248,10 @@ class PostCreate(CreateView):
         form.instance.topic.add_subscriber(self.request.user)
         """ DEACTIVED: Email subscribers when a new comment is posted """
         for subscriber in form.instance.topic.subscribers.all():
-            utils.mysendmail(subscriber.email, 'newpost', [form.instance.topic.title, form.instance.topic.slug])
+            utils.mysendmail(subscriber.email, 'newpost',
+                [form.instance.topic.title,
+                form.instance.topic.forum.slug,
+                form.instance.topic.slug])
         return super(PostCreate, self).form_valid(form)
 
     def get_context_data(self, **kwargs):
@@ -319,7 +325,9 @@ class PostDelete(DeleteView):
     def get(self, request, *args, **kwargs):
         topic = get_object_or_404(mymodels.Topic, slug=self.kwargs['topicslug'])
         self.obj = get_object_or_404(mymodels.Post, id=self.kwargs['id'])
-        self.obj.delete()
+        self.obj.status=0
+        self.obj.save()
+        #self.obj.delete()
         return redirect('app_forum-topic-list', topic.forum.slug, topic.slug)
 
 
